package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````M1<``#0```#4L0````0`!30`(``)
M`"@`'``;``$``'`HGP``*)\``"B?```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````TGP``-)\```4```````$`
M`0```)"M``"0K0$`D*T!`+`"``#($@``!@```````0`"````G*T``)RM`0"<
MK0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DD*T`
M`)"M`0"0K0$`<`(``'`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50"4TAA(RY9D$R5&*]]N,.$AGZ9&1Q$```!1````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%$```!2````5@``
M`%L```!<````8P```&0```!E````9P```&@`````````:@```&L```!L````
M;@```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````#,$@````````,`"P``````F*T!```````#`!0`
MN`(`````````````$@```&8#`````````````!(````Z`P`````````````B
M````?P,`````````````$0```!P$`````````````!(````1````````````
M```@````*0(`````````````$@````P#`````````````!(```!7`P``````
M```````2````)0$`````````````$@```)T#`````````````!$```#(````
M```````````2````TP(`````````````$@```)<!`````````````!(```"_
M`@`````````````2````F```````````````$@```"`!`````````````!(`
M``#:`@`````````````2````:0(`````````````$@```#@"````````````
M`!(```!Z`@`````````````2````AP(`````````````$@```!4!````````
M`````!$```![`0`````````````2````]P``````````````$0```$D!````
M`````````!(````3`P`````````````2````!0,`````````````$0```!P#
M`````````````!(```#6```````````````2````Q0$`````````````$@``
M`"$"`````````````!(```"R`0`````````````2````\P(`````````````
M$@````D"`````````````!(```"^`0`````````````2````;0,`````````
M````$@```%<!`````````````!(````M```````````````@````G`(`````
M````````$@```$H"`````````````!(```"J`@`````````````2````T`$`
M````````````$0```'@``````````````!(````I`P`````````````2````
MIP``````````````$@```!`"`````````````!(```!)`P`````````````2
M````LP``````````````$@```%<"`````````````!(```!P`0``````````
M```2````@0(`````````````$@```+$"`````````````!(````V`0``````
M```````2````:@``````````````$@```"H!`````````````!(```"G`0``
M```````````2````Q0(`````````````$@````0!`````````````!(```"5
M`@`````````````2````7P,`````````````$@```*,"`````````````!(`
M``")`0`````````````2````AP``````````````$@```(`#````````````
M`"$````\```````````````@````,`,`````````````$@```.@`````````
M`````!(```!G`0`````````````2````4```````````````(````($#````
M`````````!$```#[`@`````````````2````3P(`````````````$@```(\"
M`````````````!(````#`@`````````````2````Z`(`````````````$@``
M`&`"`````````````!(```#O`0`````````````2````T0,``%C``0``````
M$``8`"4$``#-7@``4````!(`#0#S`P``?%\````````2``X`2@0``"E4``#P
M!P``$@`-`'H#``#Y%0``O`$``!(`#0#Y`P``&4\```0````2``T`P@,``$"P
M`0``````$``8`+@$```=3P``M`$``!(`#0"R!```S!(````````2``L`Y00`
M`!E<``"T`@``$@`-`+8#``!`L`$``````!``&``Q!```T5```!8````2``T`
M9`0``(1?```$````$0`/`.0#``!8P`$``````!``&`#<`P``6,`!```````0
M`!@`L`0``/U-```X````$@`-`,4$``")4P``H````!(`#0#7!```&5,``&``
M```2``T`5P0```"P`0``````$``7`#X$``#I4```K````!(`#0"O`P``0+`!
M```````0`!<`F00``#RP`0`$````$0`7`.D#``!Y7P```@```!(`#0")!```
M/5\``#P````2``T`700``+47````````$@`-`%D$````L`$``````"``%P`*
M!```>5,``!`````2``T`T`,``%C``0``````$``8`',$``"!3@``F````!(`
M#0"C!```E5$``(0!```2``T``&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A
M<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O
M<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV
M`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S
M961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B
M;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L
M:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L9"UL:6YU>"UA<FUH9BYS;RXS`%]?
M<W1A8VM?8VAK7V=U87)D`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R
M=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`
M<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP
M9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E
M;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````
M```````"``(``@`"``(````#``(``@`"``0````"`````@```````@`"``(`
M`@`"`````````````@`"``(```````,````"``,``@`"```````"``(``@``
M`````@````,``@````(````"``(````````````"`````@`"``(```````(`
M```"``````````(``@`"``(``P`"``(``P`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
MB0,``!`````@````%&EI#0``!`#[!`````````$``0#?`0``$````"`````4
M:6D-```#`/L$`````````0`!`"X"```0`````````!1I:0T```(`^P0`````
M``"0K0$`%P```)2M`0`7````N*\!`!<```#<KP$`%P```.2O`0`7````[*\!
M`!<````$L`$`%P````RP`0`7````$+`!`!<````8L`$`%P```!RP`0`7````
M(+`!`!<````DL`$`%P```"BP`0`7````,+`!`!<````TL`$`%P```#RP`0`7
M````O*\!`!4%``#`KP$`%0@``,2O`0`5#0``R*\!`!40``#,KP$`%1D``-"O
M`0`5&P``U*\!`!4>``#8KP$`%2D``."O`0`5+0``Z*\!`!4X``#PKP$`%4(`
M`/2O`0`51```^*\!`!5(``#\KP$`%4D``+BN`0`6`P``O*X!`!8$``#`K@$`
M%@4``,2N`0`6!P``R*X!`!8)``#,K@$`%@H``-"N`0`6"P``U*X!`!8,``#8
MK@$`%@X``-RN`0`6#P``X*X!`!81``#DK@$`%A(``.BN`0`6$P``[*X!`!84
M``#PK@$`%A4``/2N`0`6%@``^*X!`!87``#\K@$`%A@```"O`0`6&@``!*\!
M`!8<```(KP$`%AT```RO`0`6'P``$*\!`!8@```4KP$`%B$``!BO`0`6(@``
M'*\!`!8C```@KP$`%B0``"2O`0`6)0``**\!`!8F```LKP$`%B<``#"O`0`6
M*```-*\!`!8I```XKP$`%BH``#RO`0`6*P``0*\!`!8L``!$KP$`%BX``$BO
M`0`6+P``3*\!`!8P``!0KP$`%C$``%2O`0`6,@``6*\!`!8S``!<KP$`%C0`
M`&"O`0`6-0``9*\!`!8V``!HKP$`%C<``&RO`0`6.0``<*\!`!8Z``!TKP$`
M%CL``'BO`0`6/```?*\!`!8]``"`KP$`%CX``(2O`0`6/P``B*\!`!9```",
MKP$`%D$``)"O`0`610``E*\!`!9&``"8KP$`%D<``)RO`0`62@``H*\!`!9+
M``"DKP$`%DP``*BO`0`630``K*\!`!9.``"PKP$`%D\``+2O`0`64```"$`M
MZ4D!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y<2;`0``QH_B&<J,XL3[O.4`QH_B
M&<J,XKS[O.4`QH_B&<J,XK3[O.4`QH_B&<J,XJS[O.4`QH_B&<J,XJ3[O.4`
MQH_B&<J,XIS[O.4`QH_B&<J,XI3[O.4`QH_B&<J,XHS[O.4`QH_B&<J,XH3[
MO.4`QH_B&<J,XGS[O.4`QH_B&<J,XG3[O.4`QH_B&<J,XFS[O.4`QH_B&<J,
MXF3[O.4`QH_B&<J,XES[O.4`QH_B&<J,XE3[O.5X1\!&`,:/XAG*C.)(^[SE
M`,:/XAG*C.)`^[SE`,:/XAG*C.(X^[SE`,:/XAG*C.(P^[SE`,:/XAG*C.(H
M^[SE`,:/XAG*C.(@^[SE`,:/XAG*C.(8^[SE`,:/XAG*C.(0^[SE`,:/XAG*
MC.((^[SE`,:/XAG*C.(`^[SE`,:/XAG*C.+X^KSE`,:/XAG*C.+P^KSE`,:/
MXAG*C.+H^KSE`,:/XAG*C.+@^KSE`,:/XAG*C.+8^KSE`,:/XAG*C.+0^KSE
M`,:/XAG*C.+(^KSE`,:/XAG*C.+`^KSE`,:/XAG*C.*X^KSE`,:/XAG*C.*P
M^KSE`,:/XAG*C.*H^KSE`,:/XAG*C.*@^KSE`,:/XAG*C.*8^KSE`,:/XAG*
MC.*0^KSE`,:/XAG*C.*(^KSE`,:/XAG*C.*`^KSE>$?`1@#&C^(9RHSB=/J\
MY7A'P$8`QH_B&<J,XFCZO.4`QH_B&<J,XF#ZO.4`QH_B&<J,XECZO.4`QH_B
M&<J,XE#ZO.4`QH_B&<J,XDCZO.4`QH_B&<J,XD#ZO.4`QH_B&<J,XCCZO.4`
MQH_B&<J,XC#ZO.4`QH_B&<J,XBCZO.4`QH_B&<J,XB#ZO.4`QH_B&<J,XACZ
MO.4`QH_B&<J,XA#ZO.4`QH_B&<J,X@CZO.4`QH_B&<J,X@#ZO.4`QH_B&<J,
MXOCYO.4`QH_B&<J,XO#YO.4`QH_B&<J,XNCYO.4`QH_B&<J,XN#YO.4`QH_B
M&<J,XMCYO.4`QH_B&<J,XM#YO.4`QH_B&<J,XLCYO.4`QH_B&<J,XL#YO.7P
MM8FP6DQ;2WQ$!9`$D06H`Y($J>98`ZHS:`>3__<^[U5*5DNB6.!8$48$\'O\
M5$OC6!]X`"]MT%)+Y5@H:/_WVN^0^`XT`D8H:$/P`@."^`XT__?0[P6;!3.S
M\8!/D/@.)$+P`0*`^`XD;=*8`/_WVNY%2P2=3_`$#'M$0TI$22]H>D0<:'E$
M0DM[1,/X!,!"8`6:P6`!*IA@!V#(ORL=A&#$OP7K@@4`\0P!!=U3^`1+G4)!
M^`1/^=$W3P+Q@$$`)`,Q?T0`E$#X(4`#1CUI`S(R22A&>43_]RSO!$9(LR]-
M!J]]1"AI__=R[BU(.49X1`/P8?D0LRM+>T08:?_W0N[_]PSO!YHS:"!&FD(J
MT0FP\+W_]WKN)$IZ1!!A(+/_]RKN%TOE6"AH__=D[X#X@7:#YSAI__<T[P1&
MT.?H:$"Q!/#'^]?G&4L:2.%8>$3_]\+N&$@Y1GA$`_`M^>A@`"C)T.WG__<:
M[@$@__>*[JB8`0`8`0``/`$``$0!```D`0``(`$``,:9`0!&3```1DP``+Z9
M`0"$F0$`8S<``&29`0"020``3ID!`"Z9`0`T`0``5DH``,1(``!/\``+3_``
M#@*\:D8$M`&TW_@DH`BCFD3?^"#`6O@,P$WX!,T&2UKX`S`&2%KX``#_]S+N
M__?H[L"6`0`,`0``.`$``$`!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$2
M___JH)8!`"P!```'2PA(>T0(2GA$`S,;&GI$!BL#V05+TU@#L1A'<$<`OQB8
M`0`4F`$`>I8!`!0!```(20E(>40)2WA$"1I[1(D0`>O1<4D0`]`%2IM8`[$8
M1W!'`+_HEP$`Y)<!`$R6`0!,`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(2WM$
M&&C_]S+M__>]_P9+`2)[1!IP"+VREP$`')8!`!`!``!FEP$`DI<!``=("+5X
M1`)H!DM[1!*YO>@(0+OG!$J;6``K^-"81_;GS)0!`-J5`0!(`0``W_C$+@#Q
M>`S?^,`^+>GP3WI$K?4_?0#Q.`4<K``F`)0:D--8S>D&B1N3&VB]DVAH"#4#
MEA`T!98#"@*3`PX$D]WI`B,!!MWI!(D`(P+T?T)5^`A\2.H""$_J`"I)Z@,)
M945"1@KT?P!"Z@$"1/@,;$M&/[I/\``!0NH``D/J`0-$^!!\1.D"(]'1#?%H
M#`WU&GYD1OSI`@'4Z1QGU.D2(]3I!D5R0'M`8D!K0$)`2T"0&/1%3^K2>$CJ
M0PA/\``#0.H(`LSI("/CT1J8`"4`F2]&T.D`--'I`(FC1@`D)D;-Z09G7D::
M1G4!!D;0Z0(!1>K:9<WI"*L/]KQ<W.D`O"I&S>D0`3!&UND$9QOK"`M,ZPD,
MV$;-Z01G!D;0Z08!X4;6Z0AGW>D$O,WI"@%01LWI%&=$`=WI"F<B0]WI%$6+
MZ@8+C.H'#!3K"`1>1MWI$*M%ZPD%H$9G1ACK`@A41@3J!@2I1EU&)D8%Z@<%
MW>D*-$GQ``DO1EU&<T"M!P>5?$`>1@>;&.L&`E5&)T9#ZIH#!Y-)ZP<#5$:H
M"$#JBW";1J,'`)P&DQ=&3_``"$_P``G-Z0)XI$:21M3I`D7=Z08C2T;=Z0*)
MS>D&10)#S>D,(T1&W>D$B>8.W>D"18CJ`@B)Z@,)#_;00]/I`"-&ZD46W>D&
M1:0874$B1BM&W>D(103J"`0%Z@D%H$8"G*E&8`'=Z0I%,$.D&%U!S>D&1=WI
M!#3=Z09G@^H(`X3J"03=Z0B)]AAG0<WI!F='1KP(W>D&9T3JB70V&$!&3^J`
M<D?Q``<B0]SI!$4*Z@(*S>D.9Q-&W>D.B<WI%D4`)2Q&"^H%"\WI$C1/\``)
MW>D6-$_J21?-Z0:K1^K89P_V*$O;Z0"K3^I(%D_JV6$`(!KK`PK=Z0PC2^L$
M"]WI!$44ZPH$1>L+!=WI`JLBZ@H*(^H+"U)&6T9'Z@8*0>H'"]WI!F?-Z1:K
MW>D"JQ9#I!E'Z@,'?4%11B9&C`@6F1;K`0K=Z0)G1?$`"\WI%JM/\``+S>D"
MJT3JAW2R!R)#W>D"1=SI!F<`(9-&S>D&`6L!!Y,/]I0ST^D`(T_P``S@#I(9
M0.I%$'M!%D8?1MWI#B/-Z0Z\`NH+`@/J#`.21@>:FT9"ZM1C!Y/=Z0PC9`$&
ME)(9W>D&17M!%D8$0Q]&W>D2(P"8(NH(`B/J"0-*Z@(*2^H#"Q;K"@9/ZHES
M1^L+!Q;K!`M'\0`,0^J8`T_JB')>1F=&3_``#-A&&D/-Z1AG8T;0Z0AG3_``
M"0_V_"S<Z0"\3^I)%<WI#"-%ZMAE&^L&"T_J2!1,ZP<,3^K985Y&W>D6JP`@
M"NH""@OJ`PO=Z1(CDAG=Z0)G0^L,`\WI!B/=Z0XC3_``#"+J!@8CZ@<'2NH&
M"DOJ!PO=Z09G%NL*!D7J!`I'ZPL'0>H%"\WI!JO=Z0*K44:,"`:9%NL!"D_P
M``%'\0`+W>D"9\WI%JM/\``+S>D"JT3JAW2R!R)#`)[=Z0)%S>D&`9-&UND*
M9VL!!Y,/]D0CT^D`(^`.S>D2O$#J11"2&7M!%D8?1MWI&","Z@L"`^H,`Y)&
M!YJ;1D+JU&,'D]WI#B-D`=Q&DAE[019&'T;=Z0PC!I3=Z09%(NH(`DKJ`@LC
MZ@D#3.H##!;K"P9$Z@`$`)E'ZPP'3^J)<Q;K!`M#ZI@#1_$`#$_JB'+-Z1B\
M3_``#-A&T>D,9QI#8T8/]K0<W.D`O$_P``G-Z0XC3^I)%1OK!@M%ZMAE3.L'
M#$_J2!1>1MWI%JM/ZMEA`)@*Z@(*"^H#"]WI#".2&=WI`F=#ZPP#S>D&(]WI
M$B-/\``,(NH&!B/J!P=*Z@8*2^H'"]WI!F<6ZPH&1>H$"D?K"P=!Z@4+S>D&
MJ]WI`JM11HP(!ID6ZP$*3_```4?Q``O=Z0)GS>D6JT_P``O-Z0*K1.J'=+('
M(D/=Z0)%T.D.9P`@DT;-Z08!:P$'DP_V^`/3Z0`CX`[-Z0R\0.I%$)(9>T$6
M1A]&W>D8(P+J"P(#Z@P#DD8'FIM&0NK48P>3W>D2(V0!!I3<1I(9W>D&17M!
M%D8$0Q]&W>D.(P`@(NH(`B/J"0-*Z@(+3.H##!;K"P9/ZHES1^L,!Q;K!`M'
M\0`,0^J8`UY&3^J(<F=&S>D89P">3_``#-A&&D-C1@_V:`S<Z0"\UND09T_P
M``G-Z1(C3^I)%1OK!@M%ZMAE3.L'#$_J2!1>1MWI%JM/ZMEA"NH""@OJ`PO=
MZ0XCDAG=Z0)G0^L,`\WI!B/=Z0PC3_``#"+J!@8CZ@<'2NH&"DOJ!PO=Z09G
M%NL*!D7J!`I'ZPL'0>H%"\WI!JO=Z0*K44:,"`:9%NL!"@"91_$`"]WI`F?-
MZ1:K3_``"\WI`JM$ZH=TL@<B0]WI`D71Z1)G`"&31LWI!@%K`0>3#_*L<]/I
M`"/@#LWI#KQ`ZD40DAE[019&'T;=Z1@C`NH+`@/J#`.21@>:FT9"ZM1C!Y/=
MZ0PC9`$&E-Q&DAG=Z09%>T$61@1#'T;=Z1(C`)@BZ@@"(^H)`TKJ`@M,Z@,,
M%NL+!D_JB7-'ZPP'%NL$"T?Q``Q#ZI@#S>D8O$_JB')/\``,V$;0Z11G&D-C
M1@_R('S<Z0"\3_``"4_J2!0;ZP8+3^I)%4SK!PQ%ZMAE7D;=Z1:KS>D,(T_J
MV6$*Z@(*"^H#"]WI$B,`()(9W>D"9T/K#`/-Z08CW>D.(T_P``PBZ@8&(^H'
M!TKJ!@I+Z@<+W>D&9Q;K"@9%Z@0*1^L+!T'J!0O-Z0:KW>D"JU%&C`@&F1;K
M`0I/\``!1_$`"]WI`F?-Z1:K3_``"\WI`JM$ZH=TL@<B0P">W>D"1<WI!@&3
M1M;I%F=K`0>3#_)D8]/I`"/@#LWI$KQ`ZD40DAD`F7M!%D8?1MWI&","Z@L"
M`^H,`Y)&!YJ;1D+JU&,'D]WI#B-D`0:4W$:2&=WI!D5[019&!$,?1MWI#",B
MZ@@"(^H)`TKJ`@M,Z@,,%NL+!D_JB7-'ZPP'%NL$"T?Q``Q#ZI@#S>D8O$_J
MB')/\``,V$;1Z1AG&D-C1@_RU%S<Z0"\S>D.(T_P``D;ZP8+3^I)%4SK!PQ%
MZMAE7D;=Z1:K3^I(%$_JV6$*Z@(*"^H#"]WI#".2&4/K#`/-Z08CW>D2(T_P
M``S=Z0)G`)@BZ@8&(^H'!TKJ!@I+Z@<+W>D&9Q;K"@9%Z@0*1^L+!T'J!0O-
MZ0:KW>D"JU%&C`@&F1;K`0I/\``!1_$`"]WI`F?-Z0RK3_``"\WI`JM$ZH=T
ML@<B0]WI`D70Z1IG`""31LWI!@%K`0>3#_(84]/I`"/@#LWI%KQ`ZD40DAE[
M019&'T;=Z1@C`NH+`@/J#`.21@>:FT9"ZM1C!Y/=Z1(C9`$&E-Q&DAG=Z09%
M>T$61@1#'T;=Z0XC(NH(`B/J"0-*Z@(+3.H##!;K"P9/ZHES1^L,!Q;K!`M'
M\0`,0^J8`UY&3^J(<F=&S>D&9P">3_``#-A&&D-C1@_RC$S<Z0"\UND<9T_P
M``G-Z1(C3^I)%1OK!@M%ZMAE3.L'#$_J2!1>1MWI#*M/ZMEA"NH""@OJ`PO=
MZ0XCDAG=Z0)G0^L,`\WI#"/=Z18C(NH&!B/J!P=*Z@8*2^H'"]WI#&<`(Q;K
M"@9%Z@0*1^L+!T'J!0O-Z0RKW>D"JU%&C`@,F1;K`0H`F4?Q``O=Z0)GS>D.
MJT_P``M/ZDL51.J'=+('(D/1Z1YG`"%%ZMIE$$8`(LWI`B-/ZMIC`I-/ZDH4
M\J/3Z0`CS>D,`9(9`I5[0=WI#&<01AE&W>D&(S)`.T`61A]&W>D6(X`864'=
MZ1(C(NH(`B/J"0,60Q]#,D9/ZMMF`Y:&&#M&0>L#!]WI`@$`(@`C3^J9`2!#
M'4841LWI`D5/ZI@$`I0T&`"83^J)<T_JB')#ZI@#3_``"4_P``@"DT?Q``5+
M1M#I(&?-Z19%148/\C@YV>D`B0.1W>D"`1CK!@A)ZP<)S>D"11!#1D9/1MWI
M#HD"1@`A`"#-Z08!:0'@#@>1".H""-WI`D4)Z@,)S>D.(P>:0.I%$$+JU&,'
MD]WI$B-D`0:4DAG=Z09%>T$61@1#'T;=Z0PC`"`BZ@H"(^H+`TCJ`@A)Z@,)
M%NL(!D_JBW-'ZPD'%NL$"`">1_$`"4/JF@/-Z1B)3^J*<D_P``G"1M;I(F<:
M0TM&#_*,*=GI`(E/\``+S>D2(T_J2Q48ZP8(1>K:94GK!PE/ZDH41D9/ZMMA
M3T;=Z1:)".H""`GJ`PG=Z0PCDAE[0=WI`F?-Z08CW>D.(R+J!@8CZ@<'2.H&
M"$GJ!PG=Z09G%NL(!D7J!`A'ZPD'0>H%"<WI!HG=Z0*)04:,"`:9%NL!"`"9
M1_$`"=WI`F?-Z1:)1.J'=+('1T9/\``(S>D&>")#W>D&1='I)&>01@`AS>D"
M`6L!`Y-UH]/I`",`(>`.B4:2&<WI#(E[0:E&%D9`ZD40'T;=Z1@C`NH(`@M`
MS>D&(Z!&`YI/ZIL!0NK48P.3W>D.(V0!DAE[019&'T;=Z1(C`I3=Z09%(NH*
M`LWI!HDCZ@L#W>D"B11#-AE%Z@,%2.H`"&]!%NL(`D_JBW5'\0`#1>J:!4_J
MBG1%Z@$,F$8`FT3J!0L71@`DS>D.>``ED$8@1BE&S>D"`4_JV&$"D5Y&W>D6
M`6=&T^DF(T_P``H/\AP<W.D`O#!`S>D89P`G.4#-Z19GW>D29QOK`@M,ZP,,
MW>D&(Q;K"P9/ZDH51^L,!]WI#+Q%ZMAE`I4LZ@,#T48+0T_JVF$#D2OJ`@+=
MZ0*K3^I(%`)#`""V&$KJ!`I?01;K"@+=Z0:K1_$``Q9&'T8`(UI&S>D29Y4'
M4D:4!UI&1>J:!9$(`)I%Z@$+1.H%"MWI&$4?1LWI!JO2Z2@CA>H+!0_R@`S<
MZ0"\A.H*!``AS>D"`1OK`@L@1DSK`PQY`5Q&W>D.JP.1*4:*Z@`*94:+Z@$+
MS>D.J]WI#+QQ`0.;\@X;ZP0+`I$.F4SK!0Q#ZM9C3^J)=0.3&^L!"D7JF`7=
MZ0(!3^J(=$_JF0%$Z@4(0NI'$D7J`0D,X`"_F7F"6@````"AZ]EN`````*B5
M`0`8`0``0.H"`$SQ``L:ZP`*249`1MWI!HE+\0`+`)L`)(CJ``C-Z1BK3_``
M"P`ET^DJ(\WI`D5/ZDL4`Y1$1@_VC&G9Z0")O0?-Z0P!1>J6!1CK`@A/ZMIB
M2>L#"0.;0$9"ZDL224;=Z1*)0^K:8P.3B.H$"$1&W>D6B1CK``A)ZP$)&.L$
M`$_J2A$"D4GQ``&T!P">@$:)1MWI`@&Y"!!#1>H!!];I+"-$Z@4&&.L`"#E&
M,$;-Z0X!#_808='I``%)\0`)W>D,14_JBW6`&,WI$HE90=WI&"/-Z18!=$`&
MF6)`3_``"4_J2!841D_J21<*1MWI%@%'ZMAG3^K98X`8`I=!\0`!`Y,"&47J
MF@5!\0`#S>D&(]WI`B-/ZHIT3^J;`43J!0HR0]WI!F=%Z@$+5$:V&$?Q``==
M1C)&W>D.JSM&S>D6(P":`",?1@_V?%S<Z0"\>0&*Z@0*TNDN(\WI!D541AOK
M`@M/ZHEU3.L##$'JUF/=Z1(2VD;C1@.384!%ZI@%\@X`FPQ&#)E"ZD<2&NL!
M`$OQ``$`&4_JB'2+1D_J1A$"D4OQ``&"1D3J!0B+1MWI`@%/ZID!`"1%Z@$)
M$$,:ZP`*0$9)1MWI!HE+\0`+S>D2JXCJ``A/\``+T^DP(P`ES>D"14_J2Q0#
ME$1&#_;82=GI`(F]!\WI#`%%ZI8%&.L""-WI%A))ZP,)`YMA0$_JVF)#ZMIC
M`Y,,1@Z90NI+$ACK`0!)\0`!`!E/ZH9T`)Z)1D_J2A$"D4GQ``&`1HE&W>D"
M`;D($$-%Z@$'UNDR(T3J!088ZP`(.48P1LWI#@$/]F1!T>D``4GQ``G=Z0Q%
M3^J+=8`8S>D6B5E!W>D2(W1`S>D8`0:98D!/\``)3^I(%A1&3^I)%PI&W>D8
M`4?JV&=/ZMEC@!@"ET'Q``$#DP(91>J:!4'Q``/-Z08CW>D"(T_JBG1/ZIL!
M1.H%"C)#W>D&9T7J`0M41K881_$`!UU&,D8[1LWI$B,`F@`C'T;=Z0ZK#_;0
M/-SI`+QY`=+I-".*Z@0*S>D&14_JB74;ZP(+5$9,ZP,,0>K68]WI%A+:1N-&
M`Y-A0$7JF`7R#@";#$8,F4+J1Q(:ZP$`2_$``0`93^J(=(M&3^I&$0*12_$`
M`8)&1.H%"(M&W>D"`4_JF0$`)$7J`0D00QKK``I`1DE&W>D&B4OQ``O-Z1:K
MB.H`"$_P``O3Z38C`"7-Z0)%3^I+%`.41$8/]BPYV>D`B;T'S>D,`47JE@48
MZP((W>D2$DGK`PD#FV%`3^K:8D/JVF,#DPQ&#IE"ZDL2&.L!`$GQ``$`&4_J
MAG0`GHE&3^I*$0*12?$``8!&B4;=Z0(!N0@00T7J`0?6Z3@C1.H%!ACK``@Y
M1C!&S>D.`0_VN"'1Z0`!2?$`"=WI#$5/ZHMU@!C-Z1*)64'=Z18C=$#-Z1@!
M!IEB0$_P``E/ZD@6%$9/ZDD7"D;=Z1@!1^K89T_JV6.`&`*70?$``0(9`Y-!
M\0`#S>D&(T7JF@7=Z0(C3^J*=$_JFP%$Z@4*,D/=Z09G1>H!"U1&MAA'\0`'
M748R1MWI#JL[1LWI%B,`F@`C'T8/]B0LW.D`O'D!BNH$"M+I.B/-Z09%5$8;
MZP(+3^J)=4SK`PQ!ZM9CW>D2$MI&XT8#DV%`1>J8!?(.`)L,1@R90NI'$@WU
MN'P:ZP$`2_$``0`93^J(=(M&3^I&$0*12_$``8)&1.H%"(M&W>D"`4_JF0%%
MZ@$)W>D&11!#T^D\(QKK``I)1D!&A.H`!,WI#`%+\0`+#_:0$='I``%/ZDH8
MS>D2JT_P``N`&$_J2QE90=WI%B/-Z1@!2>K::0Z98D#-^`B03^K;8Q1&`Y,*
M1MWI&`&]!X`81>J6!4'Q``$"&4'Q``/-Z0XCW>D"([0'N0@`(T+J"`+=Z0Z)
M`)X8ZP((2?$`"<WI%HE"1LWI`B-$Z@4"1>H!`];I/F=/ZIL%'$831@.:3^I"
M&=WI#!+-Z0XT64`/]O0#T^D`(Y(9>T$?1@*;2>K3:=WI$C1+0!A&!IO6&`*;
M1_$`!S(83^J*=D_J0QA'\0`#2.H)`$_JBW<2&$?JF@=#\0`#W.D`B1%&3_``
M#!I&1^H%`\WI$A(`(@A&$49&Z@<"'T;=Z0XT3^I!&Q9&S>D&9U-`2^K0:T_J
M0!H<1@_V=`/3Z0`C$NL(`D/K"0/=Z1:)'T8,FXCJ!`A+Z@H$UAC=Z0*K1_$`
M!Q;K"`)'\0`#$AE#\0`#3^J+><WI%B,`)!-&S>D`-%M&2>J:"4_JBGB?"$CJ
M"01)Z@<%7JO=Z09X+D8E1@&<;T#3Z0`C#_8$"=GI`(E/ZD0;`)P8ZP((S>D"
M5DGK`PE+ZM1K#IQ"1DM&$AG=Z1*)`)Q#\0`#B.H'"$_J@7E)ZI`)CPA/ZD0:
M1D:4&4KJ"P)#\0`%3^J`>!3K`@I(Z@D$1?$`"TGJ!P7=Z0*))D8O1F"IB.H$
M"-WI%D71Z0`!`".$Z@@$S>D,9P_RA'?7Z0!G4D:@1@:<S>D.JS883^I#&T]!
M2^K::S893^I*&D?Q``=+Z@H`%NL(!$?Q``44ZP`*1?$`"]WI`$501LWI$JM/
M\``*3_``"T_JA7E/ZH1X2>J4"6*LKPAA1M3I`$5.`<WI`*M(Z@D*2>H'"]WI
M#'C-Z0:KA^H*!P_R!'K:Z0":`989ZP0)`9Q*ZP4*1.K09`&4TT8"G,I&W>D.
MB1KK!`1/ZH-YB.H'"$OQ``6B1D0!1D8`E!KK!@1/ZM!H1?$`!4CJ01BB1DGJ
MD@FK1MWI`$6?"&2K1.H(!$_J@G@:ZP0*2>H'!4CJ"03=Z0:)T^D`(R]&)D;-
MZ0)GB.H&"`_R@&;6Z0!62_$`"\WI%JM/\``+S>D`JP&<K1A>00";3^J!>4_J
M1!LW1DOJTVO=Z1(T#)Q)ZI`)@^H(`T_J@'@N&0"<1_$`!T_J1!KT&$KJ"P9'
M\0`%BP@4ZP8+1?$`#$CJ"01)Z@,%9JF@1MWI`B/1Z0`!J4;-Z0Z)`"</\@1I
MV>D`B6)`!IQ>1ACK``C-Z0R\2>L!"4_J1QM`1DOJUFM)1MWI%HD`&4_J1AJ(
MZ@((0?$``4_P``Q"1H082NH+`$'Q``44ZP`*849%\0`+W>D`15!&S>D2JT_J
MA7E/ZH1X2>J4"6BLJPA(Z@D*U.D`14GJ`PM21MWI#II;1@_RA%O;Z0"KS>D6
M10`D`"7-Z0!%3`$!E,WI!B.)Z@()W>D6-,(.0NI!$D_JAG@3ZPH#1.L+!)I&
M`9NC1D/JT&,!D]WI##0"G(/J"0-/ZH=Y&NL$!$GJE@E+\0`%:JZB1D0!`)0:
MZP,$1?$`!0`CHD:K1MWI`$6]"!1#&NL$"DOQ``O-Z1:K4D;-Z0`C2>H%`TCJ
M"0+=Z0:)UND`JXCJ`@B)Z@,)S>D,(P`B1$9-1@_RV$G9Z0")`"/-Z0(C&.L*
M"$GK"PG"1LM&W>D`B4-&VPX"DP*;0^I)$]WI$HD"DXCJ!`@.G(GJ!0G-Z1*)
M&NL$`T_JD05+\0`$W>D`JYA&4T9/ZH!Z7@%;1ML.`Y,2FT_J@7M+ZI`+;*D8
MZP,(1/$`"4)&2T;=Z0*)2.H&"!+K"`9*Z@L"0_$`!TOJ!0.P1M'I`$6Y1MWI
M#&?-Z0XC3^I(&A9#S>D2B4_P``DP1MWI%F=/ZDD;!D!+ZMAK,$;=Z0QG%D`/
M\AQ#T^D`(S!#2^H*!A(9:T$=1@:;TAA%\0`#$AA#\0`#S>D"(]WI`*M;1IT'
M4T;=Z0*KF`ANJQKK!@K=Z0!G2_$`"\WI%JM/\``+S>D`JT7JE@5`ZH=PM`>Y
M"$3J``I%Z@$+W>D.1<WI!JO=Z1*\1.H*`M/I``$+Z@(+#)L!GEI&W>D&JP_R
ME#S<Z0"\`)\$Z@H$&^L`"T_J1A9,ZP$,&^L#"P";1NK79@.60NH$!DSQ``P;
MZP8+3^K39$_J0Q,"DTSQ``P!FT_JB7'=Z0)G0>J8`4_JB'!$ZD,43^J9`R9#
MW>D&11OK!@M/\``)3/$`#,WI$KS81D#J`0M!Z@,,1.H+`LWI#+QPJ]WI%JM/
MZDD6W>D,O$;JV&8*Z@(*T^D``03J"P0.FU)&#_+P*]OI`*L#ED+J!`8:ZP`*
M3^K89$OK`0L:ZP,*3^I($P*32_$`"QKK!@K=Z0)G1.I)%$OQ``L`)R9#-$8!
MGAKK!`H!G$OQ``O-Z1:KL0<`GJ,(0>J6`;`'5D;-Z0!GW>D,14#J`0I!Z@,+
MS>D.J]WI$KQ$Z@H"<JL!G@OJ`@L`G]/I``%:1MWI#JL/\F0LW.D`O'8!!IL$
MZ@H$&^L`"T;JUV9,ZP$,&^L#"P";3/$`#`.60NH$!AOK!@M/ZHEQ3^K39$_J
M0Q,"DTSQ``P!FT'JF`'=Z0)G3^J(<$3J0Q1/ZID#)D/=Z0Y%&^L&"T_P``E,
M\0`,S>D2O-A&0.H!"T'J`PQ$Z@L"S>D&O'2KW>D6JT_J21;=Z0:\1NK89@KJ
M`@K3Z0`!!.H+!`R;4D8/\L0;V^D`JP.60NH$!AKK``I/ZMAD2^L!"QKK`PI/
MZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<2_$`"\WI
M%JNQ!P">HPC=Z09%0>J6`;`'0>H#"W:K5D;-Z0!G0.H!"@&>T^D``43J"@+-
MZ0RKW>D2O'8!#IL+Z@(+`)]:1MWI#*L/\C0<W.D`O$;JUV8$Z@H$`Y8;ZP`+
M0NH$!DSK`0P;ZP,+`)M,\0`,&^L&"T_JB7%,\0`,0>J8`=P.6P$"DT_JB'`!
MF]WI`F=$ZD,43^J9`R9#W>D,11OK!@M/\``)3/$`#,WI$KS81D#J`0M!Z@,,
M1.H+`LWI#KQXJ]WI%JM/ZDD6W>D.O$;JV&8*Z@(*T^D``03J"P0&FU)&#_*8
M"]OI`*L#ED+J!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*32_$`"QKK!@K=Z0)G
M1.I)%$OQ``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(W>D.14'JE@&P
M!T'J`PM61D#J`0K-Z0!GS>D&JT3J"@+=Z1*\>JL!G@"?"^H""]/I``%:1G8!
MW>D&JT;JUV8'X*'KV6X`````W+P;CP`````/]I1LW.D`O`.6!.H*!`R;&^L`
M"TSK`0Q"Z@0&&^L#"P";3/$`#!OK!@M,\0`,3^J)<=P.6P$"DT'JF`$!FT_J
MB'#=Z0)G1.I#%$_JF0,F0]WI!D4;ZP8+3_``"4SQ``S-Z1*\V$9`Z@$+0>H#
M#$3J"P+-Z0R\?*O=Z1:K3^I)%MWI#+Q&ZMAF"NH""M/I``$$Z@L$#IM21@_V
M_%O;Z0"K`Y9"Z@0&&NL`"D_JV&1+ZP$+&NL#"D_J2!,"DTOQ``L:ZP8*W>D"
M9T3J211+\0`+`"<F0S1&`9X:ZP0*`9Q+\0`+S>D6J[$'`)ZC"-WI#$5!ZI8!
ML`=!Z@,+5D9`Z@$*S>D.J]WI$KQ$Z@H"?JO-Z0!G"^H""P&>T^D``5I&W>D.
MJP_V=%S<Z0"\=@$&FP3J"@0;ZP`+`)],ZP$,&^L#"P";3/$`#$;JUV8#ED+J
M!`9/ZHEQW`Y;`0*3&^L&"P&;3/$`#-WI`F=!ZI@!3^J(<$3J0Q1/ZID#)D/=
MZ0Y%&^L&"T_P``E,\0`,S>D2O-A&0.H!"T'J`PQ$Z@L"S>D&O("KW>D6JT_J
M21;=Z0:\1NK89@KJ`@K3Z0`!!.H+!`R;4D8/]M1+V^D`JP.60NH$!AKK``I/
MZMAD2^L!"QKK`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>
M&NL$"@&<2_$`"\WI%JNQ!P">HPC=Z09%0>J6`;`'0>H#"U9&0.H!"LWI#*O=
MZ1*\1.H*`H*KS>D`9POJ`@L!GM/I``%:1MWI#*L/]DA,W.D`O'8!#IL$Z@H$
M&^L`"P"?3.L!#!OK`PL`FTSQ``Q&ZM=F`Y9"Z@0&3^J)<=P.6P$"DQOK!@L!
MFT'JF`'=Z0)G3/$`#$_JB'!$ZD,43^J9`R9#W>D,11OK!@M/\``)3/$`#,WI
M$KQ!Z@,,A*O81D#J`0M$Z@L"T^D``<WI#KQ/ZDD6W>D6JT;JV&;=Z0Z\"NH"
M"@:;!.H+!`.64D8/]J@[V^D`JT+J!`9/ZMAD&NL`"D3J211+ZP$+&NL#"D_J
M2!,"DTOQ``L:ZP8*W>D"9TOQ``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`
MGJ,(W>D.14'JE@&P!T'J`PM61D#J`0K-Z0:KW>D2O$3J"@*&J\WI`&<+Z@(+
M`9[3Z0`!6D;=Z0:K#_8@/-SI`+QV`0R;!.H*!!OK``L`GTSK`0P;ZP,+`)M,
M\0`,1NK79@.60NH$!D_JB7'<#EL!`I,;ZP8+`9M,\0`,W>D"9T'JF`%/ZHAP
M1.I#%$_JF0,F0]WI!D4;ZP8+3_``"4SQ``S-Z1*\V$9`Z@$+0>H##$3J"P+-
MZ0R\B*O=Z1:K3^I)%MWI#+Q&ZMAF"NH""M/I``$$Z@L$#IM21@_V@"O;Z0"K
M`Y9"Z@0&&NL`"D_JV&1+ZP$+&NL#"DOQ``M/ZD@3&NL&"@*3W>D"9T3J211+
M\0`+`"<F0S1&`9X:ZP0*`9Q+\0`+S>D6J[$'`)ZC"-WI#$5!ZI8!L`=!Z@,+
M5D9`Z@$*S>D.J]WI$KQ$Z@H"BJO-Z0!G"^H""P&>T^D``5I&W>D.JP_V]!S<
MZ0"\=@$&FP3J"@0;ZP`+`)],ZP$,&^L#"P";3/$`#$;JUV8#ED+J!`9/ZHEQ
MW`Y;`0*3&^L&"P&;3/$`#-WI`F=!ZI@!3^J(<$3J0Q1/ZID#)D/=Z0Y%&^L&
M"T_P``E,\0`,S>D2O-A&0.H!"T'J`PQ$Z@L"S>D&O(RKW>D6JT_J21;=Z0:\
M1NK89@KJ`@K3Z0`!!.H+!`R;4D8/]E0;V^D`JP.60NH$!AKK``I/ZMAD2^L!
M"QKK`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<
M2_$`"[$'`)ZC",WI%JO=Z09%0>J6`;`'0>H#"U9&0.H!"LWI#*O=Z1*\1.H*
M`HZKS>D`9POJ`@L!GM/I``%:1MWI#*L/]LP,W.D`O'8!#IL$Z@H$&^L`"P"?
M3.L!#!OK`PL`FTSQ``Q&ZM=F`Y9"Z@0&3^J)<=P.6P$"DQOK!@L!FTSQ``S=
MZ0)G0>J8`4_JB'!/\``*1.I#%$_JF0,F0U=&&^L&"T#J`0I,\0`,S>D8O%Y&
M0>H#"Y"I4T9<1MWI#*O1Z0`!3_``"`_V1`S<Z0"\3_``"<WI#C1\`<WI`HD;
MZP`+`Y1*Z@,(W>D.15A&S>D29T)&!IM,ZP$,W>D6B0KJ!`G=Z1*K848#G@CJ
M`@C"&$CJ"0A!\0`#44971D;JVF9)`0.6`I$2ZP@"`9Y/ZM=DW>D">$3J2Q1#
M\0`#)T.Q!P&<$NL'"P">0_$`#``GS>D6O*,(`"1!ZI8!L`=>1LWI`&=!Z@,,
M`"/-Z0(TDJH!FT#J`0O=Z0YGW>D8B>%&TND``5L!1NH+`@.3".H""`;J"P(#
MGD1&V$8/\G1\W.D`O")#-T8`GAOK``L,FTSK`0Q'ZM9G`)Y81L`83/$``8(8
M3^I&$P*30?$``P.7NT861A]&W>D"(T_P``Q"Z@L"%NL""D?Q``O=Z1)GS>D8
MJ]-&S>D"O+T'M`=%ZI8%N0A$Z@4*1>H!"P.;E*G=Z19%`IK-Z1*)B.H*",WI
M!JN$Z@@$T>D`O%L!#_+P8='I``%#ZM)CH$8.G!OK``L?1DSK`0Q3`=I&&NL$
M!`">XT9+\0`%%.L("D/J!P@!FT7Q``NT!P&>&NL("D_J@W4`FTOQ``O11K$(
MS>D6JT7JDP5/\``*1>H!"$3J!0>6J4I&/49&1MWI!GA31LWI#%;-Z0`C;T#1
MZ0")W>D810_R;&'1Z0`!?$``FQCK``A/\``')D82G$GK`0G8#ACK!`0#FTGQ
M``7=Z0")3^I'&T_J2!H4ZP8(0.I)$$7Q``F=!P*;2NH`!ACK!@A%ZI,%`IM&
M1DGQ``G-Z1*)2^K6:YP'`YM$Z@4(3^I&&ID(0$9%Z@$)F*M)1MWI#(G3Z0`C
MB.H`",WI#@$&F41&#_+@6=GI`(D8ZP((2>L#"=WI%B,8ZP$`3_```X+J!`))
M\0`!%$80ZP0(2NH+!-WI`+Q!\0`)`"+-Z0(C3_``"F%&54:)!P.1`YA91HH(
M&.L$"$#JFP$#D5E&3_```$_J@7$"D6%&0NJ,<D_JD0-/\``!S>D``41&W>D"
M`4GQ``G-Z1:)P4890Q!#:P$!DXM&W>D.$IJK@D9!0,WI`JO3Z0"\B$8/\CQ2
MTND`$@&;&^L!"PR93.L"#$/JV6,!D]I&W>D2(QKK`0#C1DOQ``&"Z@@"NPB+
M1F$!D$8`D1#K"`!/ZM1BW>D`B4+J11)+\0`!3_``"4CJ`@@0ZP@*3^J&<$'Q
M``NY!T'JE@'-Z1*K0>H##$#J`0M/ZDD3`"991F)&W>D"O``GS>D`9]!&`9.+
MZ@$+G*O-Z0827D8.F=/I`*L-]1Y\#_*<0]/I`",:ZP(*2^L#"P&;&NL!`$/J
MV&,!D]WI%B-+\0`!JPAR0(M&3^I($0"1%D9/ZMAB@!G=Z0!G0NI)$DOQ``$6
M0P`G$.L&"D_JA'!!\0`+J0=!ZI0!5D;-Z0ZK`"1`Z@$*0>H#"P`E>P'-Z0!%
M448!D]WI!C3-Z0RK2T#<Z0"\#_(80M+I`!(<1@&;&^L!"P*93.L"#$/JUF/:
M1@&3&NL!`-WI$B/C1DOQ``%B0$_P``R+1G$!`)$41O(.`!G=Z0!%0NI'$DOQ
M``%/ZID#%$-E1A#K!`I/ZHAP0?$`"T_JB7%!ZI@!#?4@?$#J`0A!Z@,)5$;I
MHM+I`!+-Z1*KPD;+1LWI`JO<Z0"\:P'=Z0R)0^K48QOK`0L&F4SK`@P!D]WI
M#B.(Z@H(VD8:ZP$`XT:"Z@@"2_$``;L(D$;B#A#K"`"+1D_J1!$`D=WI`(E"
MZD422_$``4_P``E(Z@(($.L("D_JAG!!\0`+N0=!ZI8!S>D.JT'J`PQ`Z@$+
M3^I)$P`F`"?-Z0!G`9.BJ]!&649B1MWI`JO-Z082T^D`O(KJ`0J^H]/I`",,
MF59&&^L""TSK`PP!F]I&&NL!`$/JV&,!D]WI$B/C1DOQ``&K"')`BT9/ZD@1
M`)$61D_JV&*`&=WI`&="ZDD22_$``0`G%D,0ZP8*3^J$<$'Q``NI!T'JE`'-
MZ1*K0>H##$#J`0M[`<WI#+P`)``E#?4D?,WI`$4!DU9&W>D&--SI`!)/\``,
M@^H+`P_R9"O;Z0"K$>L*`1Q&0NL+`@&;BD8"F9-&0^K68QKK`0`!D]WI#B-+
M\0`!3^J9`V)`BT9Q`0"1%$;R#@`9W>D`14+J1Q)+\0`!%$-E1A#K!`I/ZHAP
M0?$`"T_JB7%!ZI@!5$9`Z@$)S>D.JT'J`PH-]29\:P'31LI&W>D,B4/JU&/<
MZ0`2B.H*",WI`JL/\M@;V^D`JP&3$>L*`4+K"P**1@:9DT;=Z1(C&NL!`$_J
MEP-+\0`!@NH(`HM&D$9A`1#K"```D4_JU&+=Z0")0NI%$DOQ``%/\``)2.H"
M"!#K"`I/ZH9P0?$`"[D'0>J6`0`G`";-Z0!G0.H!!D'J`P?=Z0(23^I)$P&3
MJ*MQ0-!&S>D2J\WI!F<.1@_R3!O;Z0"KT^D`$@&;$>L*`4+K"P)#ZMACBD8,
MF0&3DT8:ZP$`W>D.(TOQ``&K"')`BT9/ZD@1`)$61D_JV&*`&=WI`&="ZDD2
M2_$``0`G%D,0ZP8*3^J$<$'Q``NI!T'JE`'-Z0ZK0>H##$#J`0M[`<WI#+P`
M)``E#?4J?,WI`$4!DU9&W>D&--SI`!)/\``,@^H+`P_RM`O;Z0"K$>L*`1Q&
M0NL+`@&;BD8"F9-&0^K68QKK`0`!D]WI$B-+\0`!3^J9`V)`BT9Q`0"1%$;R
M#@`9W>D`14+J1Q)+\0`!%$-E1A#K!`I/ZHAP0?$`"T_JB7%!ZI@!5$;-Z1*K
M3_``"$'J`PI/\``)#?4L?,WI`(E`Z@$)4D9K`=SI`*M)1@&3S>D"$@FCT^D`
M(]WI#(D:ZP(*2^L#"P&;B.H!"$/JU&,(X`"_W+P;CP````#6P6+*``````&3
M!IG=Z0XCNP@:ZP$`2_$``8+J"`*+1F$!`)&01N(.$.L(`-WI`(E"ZD422_$`
M`4_P``E(Z@(($.L("D_JAG!!\0`+N0=!ZI8!T$;-Z0ZK0.H!"D'J`PL`)@`G
MS>D`9U9&7T;=Z0*K3^I)$P&3KJN*Z@8*S>D&9_NBTND`$E9&T^D`JP&;&NL!
M"@R92^L""T/JV&,:ZP$``9/=Z1(C2_$``:L(<D"+1D_J2!$`D19&3^K88H`9
MW>D`9T+J21)+\0`!%D,`)Q#K!@I/ZH1P0?$`"ZD'0>J4`<WI$JM!Z@,,0.H!
M"WL!S>D,O``D`"4-]3!\S>D`10&35D;=Z08TVJ+2Z0`2@^H+`]SI`*M/\``,
M&NL!"AQ&`IE+ZP(+`9L:ZP$`0^K68P&3W>D.(TOQ``%/ZID#8D"+1G$!`)$4
M1O(.`!G=Z0!%0NI'$DOQ``$40V5&$.L$"D_JB'!!\0`+3^J)<4'JF`%41D#J
M`0G-Z0ZK0>H#"@WU,GQK`=-&RD;=Z0R)0^K48]SI`!(-]39\B.H*",WI`JL/
M\M`KV^D`JP&3$>L*`4+K"P**1@:9DT;=Z1(C&NL!`$_JEP-+\0`!@NH(`HM&
M80$`D9!&X@X0ZP@`W>D`B4+J11)+\0`!3_``"4CJ`@@0ZP@*3^J&<$'Q``NY
M!T'JE@$`)P`FS>D`9T#J`09!Z@,'W>D"$D_J21,!D[2K<4#01LWI$JO-Z09G
M#D8/\D0KV^D`J]/I`!(!FQ'K"@%"ZPL"0^K88XI&#)D!DY-&&NL!`-WI#B-+
M\0`!JPAR0(M&3^I($0"1%D9/ZMAB@!G=Z0!G0NI)$DOQ``$`)Q9#$.L&"D_J
MA'!!\0`+J0=!ZI0!S>D6JT#J`01!Z@,%3^I'&U9&(4;=Z08T*D;-Z0P22T!P
MH='I``%+ZMIKS?@`L!Q&W.D`(T_J2AI/\``,$AA+0<WI#B/=Z1(C^PX"F6)`
M`9,41@I&W>D.`8`80?$``0(9W>D`14'Q``-/ZHEQS>D"(T3J"@1!ZI@!W>D"
MJT_JB'!/ZID#0.H!"$'J`PD:ZP0*0D9+\0`+2T;=Z0R)S>D2JU1&94;-Z0!%
MS>D.(XCJ`@A,I-3I`#0-]3A\W>D614_JAWO<Z0`22^J6"X3J"`1/ZI<)R1A+
MZ@D%H$8`G``CK$:ZK]WX].+@#@:<"AD!G!+K"`)`ZD00`)Q/ZD0:0.H*`$_J
MAGI*Z@L$$AC=Z0Z:HT9<`<WI!KR)Z@L)1.K2;(KJ!0K7Z0!GR$;-^`S`T49@
M1@_RL`O;Z0"KW>D2O``C#)P:ZP8*C.H)#(OJ"`O-Z1*\&NL$!E0!`I02G$_P
M``DV&=WI`D4$0R!&`)PV&-WI"`$`(8`93^J4"AJ>W>D`1<;I``%*ZH5ZW>D0
M5AN93^J$>*T82.H*"-'X`,`J1@:9W>D*5FT8#IDN1MWI%$4`)608W>D$`0`A
M$.L(`+!&&I[F1<;I`B/&Z0:)QND(1<;I!`$#T0WU/WV]Z/"/_/?Z[`"_K_,`
M@-;!8LH`````+>GX0Q]+>T0`*#G0'DJ;6-/X`)"Y\0`/,-`%>``M&+\]+12_
M`24`)171V?@`0'RQ!T:(1DY&*D8Y1B!&_/?@[1"Y8UT]*P_05O@$3P`L\M$@
M1KWH^(,%1A7X`3\`*QB_/2OYT2T:X.<!-:;K"08L1+80R/@`8"!&O>CX@TQ&
MY^<$1N7G\F0!`%`!``#PM8.P%4\%1A5+;$9_1/Y8,V@!DR%&*$;_]ZS_L+$1
M2P"8^U@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48H1O_WEO\`*.C1
M`9HS:)I"`=$#L/"]_/=^[&!D`0`8`0``4`$``"WI\$\,1M_X7)&%L%9+!D;Y
M1`IX6?@#4#TJ"+\!-"MH($8#D_SWWNP"J0=&,$;_]VW_@$8`*%/0_/?4[(="
M1ME*2P*:6?@#D$_J@@@P>``H&+\]*!2_`2``(`?0,$80^`$_`"L8OSTK^=&`
M&P(WV?@`H#A$_/>2[$KX"```*&O0V?@`('$<`I@S>%+X(``]*QB_`"L#<`G0
M0AP1^`$[$$8`*QB_/2L"^`$[]M$"1CTC`W`4^`$[`O@!/P`K^=$`(`.:*VB:
M0DK1!;"]Z/"/"/'_,!3X`3L`^`$_`"OYT>[G(DM9^`.0V?@`L-OX`#"#LUM&
M`.!01E/X!"\`\0$*`"KXT0,P@``:2GI$$VB+L0%&6$;\]P+LR?@``.BQ3^J*
M"`-&"O$!`@`A0_@B$,WX"*",YP$C$V#\]S+L`9!@L4_JB@A91D)&_/>DZP&;
MR?@`,.?GFD8((-;G3_#_,+#G_/?(ZP"_]&,!`!@!``!0`0``E&0!`#1+-4I[
M1"WI\$.?L)Y8,V@=DQ"Q`W@'1C.Y'9HS:)I"5=$?L+WH\(/\]_+K!48`*//0
MW_BH@/A$*$;\]Y;L`"@[T,-\T_$N`P?1`WT`*_/0T_$N`Q2_6T)#?0`K[-``
M\1,$.$;\]P3L@48@1OSW`.Q(1`(P_/?8ZT-&3_#_,@$A`90`EX%&_/<2[$E&
M`JH#(/SW?.P!,$A&!=`&FP/T<$.S]8!/$-#\]WCK2$;\]SSK*$;\]UKL`"C#
MT2A&_/>$[#A&_/=$ZZCG__>:_^WG_/=6ZP"_C&(!`!@!``!F$P``.+4%1A5+
M%DI[1)Q8(&C\]W+L*48`]:1R`R#\]V#L"+$`(#B](&C\]V;LT/A8,0/T<$.S
M]8!/"=`@:/SW7.S0^%@Q`_1P0[/U($_IT2A&`B'\]PCLL/J`\$`).+VH80$`
M(`$``"WI\$.M]8!=(4V#L"%+#?6`5GU$`:R`1A]([U@$-HE&0/;_<B%&>$0[
M:#-@_/<JZP`H(=U&'J-=X[$&1C)&+R$@1OSWV.NXL11+ZU@8:/SW(.PS1B)&
M04;\]^KK#?6`4P0S&F@[:)I"$-$-]8!=`["]Z/"#`"[AT0A+ZU@8:/SW".Q*
M1D%&_/?XZN?G_/?4ZCIA`0`8`0``.A(``"`!```0M0A,"$M\1.-8&&C\]_#K
M!DH'2P=)HEA[1'E$O>@00/SW9KNF8`$`(`$``!P!``!P$0``MA$```U+#DI[
M1!"U@K"<6"!H_/?4Z__WV?\@:/SWSNL`(0A+`9$(2GM$"$EZ1`"3>43\]W#K
M`K`0O0"_<&`!`"`!``!D%```N0T``(@1```A2R)*>T3PM:WU`%V=6(>P#?4`
M4@.N%#(=3"MH?$038/SWYNH;2T'R`0(!(7M$C>@1`#!&_/<&ZP`H(=L-]8!7
M,$80-T_T@%(Y1OSWBNH$'A;;8!S\][3J!D8HL3E&(D;\]SKJ`",S50WU`%,P
M1A0S&F@K:)I"!=$-]0!=![#PO0`F\>?\]T;J)&`!`!@!``!P$0``5!$``/_W
MLK\MZ?!/K?6!7=_X=(&#L%U+!$;X1`WU@5);2`0R6/@#,`WQ*`D-1GA$J?$(
M`063&V@38/_W+_TO(09&($;\]Z+JF+%22"%&>$3_]Y[]($8-]8%3!#,::`6;
M&VB:0D#PBH`-]8%=`["]Z/"/($;\]W[J1TEY1()&*$;\]^CJ!T8`*-_01$O?
M^!"Q>T0&DT-+^T1[1`>3.W@`*TO0+K$Y1C!&_/><Z0`H2M`X1OSW8.I"'KL8
MNEPO*@;1`"$9<`$X$_@!+2\J^=`*\0$#&$2P]8!?M]JI\00%,DH!(5M&>D0`
MEP&2*$9/](!2`I3\]U[J+4M8^`-P.&C\]^SJ*48`]:1R`R#\]\+J2+DX:/SW
MXNK0^%@Q`_1P0[/U`$\<T"))`"!Y1/SWE.H'1@`OBM`[>``KL]%NL0:9,$;\
M]U#IX+D;20`@>43\]X+J!T8`+^[1>.<'GP$@M^<!(2A&_/=RZ@`HW-$32"E&
M>$3_]P[]*$;\]RKJ;.?\]X#I!I\!(*/G`+]Z7P$`&`$``-(0``"^$```HA``
M`&P0``"*$```9!```$00```@`0``]`\``-(/``">#P```W@[L4(<+RL(OQ!&
M$O@!.P`K^-%P1P"_.+68LP5X!$:%L_SWRND!."(8E$(,TB-<+RLPT5,>`N`1
M>"\I*]&<0AI&`_'_,_?1E$(9T`$Z`^`1>"\I!-$:1I1"`O'_,_?3$AN3'+/U
M@%\3V!1((48!,D_T@%-X1`1&_/<>Z2!&.+TO+171`B#\]W3I$+$N(@*`.+T`
M(#B]4QX"X!%X+RG5T)Q"&D8#\?\S]].40L[1Y^<#2+WH.$!X1/SWJ+D07P$`
MM@X``"WI\$&,L$9,`JU&3WQ$1DX,-']$W_@4@0_,^$2_60&N#\4/S-?X`,`/
MQ21H0$C-^"S`>$0L@/_W-_P^2'A$__<S_#U(>$3_]R_\/$AX1/_W*_P[2'A$
M__<G_#I(>$3_]R/\.4AX1/_W'_PX2'A$__<;_$!&__<8_#5(>$3_]Q3\-$AX
M1/_W$/PS2#%&>$3_]\7[&+$!1D!&__<Z_"](,49X1/_WN_L@L0%&+4AX1/_W
M+_PL2#%&>$3_][#[B+$!1BE(>$3_]R3\*$DI2'E$>$3_]Q[\"YH[:)I"'M$,
ML+WH\($D2#%&>$3_]YC[*+$!1B%(>$3_]PS\YN<@20HB#?$9`'E$_/>*Z0`H
MW=$<2`WQ(P%X1/_W_/O6Y_SW<N@`O^0-```"70$`&`$``.(.``!Z#@``?`X`
M`'P.``"`#@``@`X``(@.```<#@``A`X``(X.```*#@``B`X``(@.``"0#@``
MD@X``+X-``"L#@``!@X``'(.``#^#0``:@X``-X-```221-*>4032Q"U>T2,
M6(*P&&@C:`&30QP%T`&:(VB:0A+1`K`0O0Q(:49X1/_W-/LPL0!X,"@8OP`H
M%+\!(``@!DM[1!A@Z.?\]QCHC%L!`!@!``#B7`$`0@T``*I<`0`(M?OWUN_[
M]\CO`+$`:`B](4LB2GM$+>GP08:PG%@%1A]/!*DC:']$.$8%D__W!/LI1F"Q
M`W@&1DNQ^_><[UBQ!9HC:)I")-$&L+WH\($52'A$__=K^_/G*$;\]UKH@$8P
M1OSW5NA`1`(P_/<NZ`Y+3_#_,@*6>T0!DPQ+`2$`E7M$@$;\]V+H048X1O_W
M3OO6Y_OWQ.\`OQQ;`0`8`0``<@T``$@-``!"#```/`P``"WI\$^M]0%-W_AD
M1Y.P4JO?^&"'?$0+DR(='D;?^%@W^$0,D*;Q^`<'R@3Q$`Q8^`,PIO'@"R@T
MIO'L"=I&_#X=1@V3A^@'`+SH#P#5^`#@JN@/``WU`4.<Z`,`1#/#^`#@BN@#
M`)3H!P")Z`<`,4;?^`@'>$3_]X?Z(+$#>`1&`"M`\(N!__=C_P5&`"A<T"A&
M^_?F[T```3#[][[O*WB!1H.QW_C8IDQ&^D0`DR!&4T9/\/\R`2$"-/OW\.\5
M^`$_`"ORT0N;4_C@#!BY%>!;^`0/D+$Q1O_W5OH$1@`H]M`#>``K\]#_]_+[
M`"COT"!&^_?B[P5&`"@UT0`D5_@D4(6S*WASLRA&!/$!"@?KA`3_]]W[6+E4
M^`1?';,K>`NS*$8*\0$*__?2^P`H\]`H1E1&^_?`[P`HX-`%1A/@^_>Z[P`H
M0/`Y@5GX!`L`*`#P*X$Q1O_W%_H`*/70`W@`*_+0[.<`)2A&W_@8=OOW>.]_
M1`1&2$;[]W+O!$0$\@1$($;[]TCOW_C\-4_P_S(!(7M$`9/?^/0US?@,D'M$
M`)4"EX-&^_=Z[UA&3_3@<?OWD.\!,"[0W_C4-5CX`W`X:/SW`.A91@#UI'(#
M(/OW[N\%1@`H-=#?^+@%`2$,FP`DW_BT)5CX```;:'I$S?@`L`!H^_>,[PWU
M`4,@1D0S&F@-FQMHFD)`\)R"#?4!31.PO>CPC_OW/.\":!$JR]#?^'`%`2$,
MFP`D6/@``!MH`9+?^&@ES?@`L'I$`&C[]VCOV><X:/OWON_0^%@Q`_1P0[/U
M@$^_T3AH^_>T[]#X8)'[]T[N@46VT3AH^_>J[]#X6#'#\P@#L_7@?ZS1($;[
M]\KN,48$1M_X%`5X1/_W>_D`*`#PE(`,FQYH^_<,[P%&,$;_]R;\!D8`*`#P
MB(`P1OOWUNX#*`=&$-W?^.04!#@P1'E$^_<$[D"Y!"\`\."!-T07^`4\+RL`
M\-J!__<'_C"Y`48P1OOWD.X.D``H:='?^+04W_BT!'E$W_BP='A$W_BPE/_W
MN?E_1/OWG.[?^*0TW_BD%$_P_S)[1`&3W_B<-'E$W_B<A+I&`Y%[1,WX`+`!
M(?E$^$1?1@*0($;[]ZSN%.#[]Z3N`V@1*Q?1^_=Z[@$US?@0@#)&`Y5+1LWX
M!*`!(0"7`I`@1OOWENY/].!Q($;[]Z[N0QP&1N+0NT981OOWR.W?^#P$(49X
M1/_W=/D@1O_WX_TMY__WX/T@1OOWBNX$1B;G#2#?^!Q4^_<R[E,C?42!1G/F
M!49GY@R;'FATYPN?;_`1`@(E`)4['PR3'D9/\/\S^_<&[C%&!B(.F/OWANT7
M^`0\&[ES>$,K`/!R@0`E`"(`(P"5#IC[]_+M"Y[0H='I``&F\<@*SZ/3Z0`C
MROAX4,KI`@&F\9`!#Y',H='I``'*Z00CS*/3Z0`CRND&`<NAT>D``<KI"",`
M(@`C$)3*Z0HCRND,(T;I,@'-^$2P3_0`0@R9#IC[]TCM!!YZW><7VND*(R9&
M^0!!ZE1Q!Y'A``:1W>D&B4_P``D8ZP((F44(OY!%VND,(P+2`3)#\0`#<0_:
M^'@`0>K'`0B1>0\)D=WI"%;*Z0J)K1A>02I&,T;*Z0PC`"A*T,#Q0`@/FZ!%
M#)D81*B_H$9"1OOW+.W:^'@P0T3*^'@P0"NXT0R;4$:DZP@$F$3[]^K_/RPF
MW4`\"YTD\#\+"/%`#@OQ@`G!1*[Q0`:E\9`,,&@0-E;X#!QG1E;X""P,\1`,
M5O@$/'9%#\?QT5!&^_?*_P;Q0`[.1>;1"_%`"P3P/P381$%&2",B1@^8^_<Z
M[<KX>$!_Y]WX,(#*YPN;#IBC\9`'$)S=^$2P^_<8[MKX*%"`(=KX,&#%\\4"
M4QPX*[E4`/.:@/@8P_$X`@`A^_>F[5!&*@XS#HKX=""*^'-@BOAW4(KX<#`S
M##8*BOAQ,(KX<F`K#"T*BOAU,(KX=E#[]X'_"YC:^`A@H/%$`MKX$%!0^,C,
MH/$P!Z#Q"`C?^.R1U7)/ZAQ!3^H<8U%P^43:^"`0`/A$/-KX&`""^`/`3^H<
M+-%T@O@"P$_J%FS0<X+X!,!/ZA9,@O@%P-9Q-@J6<2X.%G(N#"T*5G*5<A9&
M!0X5<P4,``I5<SU&D',(#A!T"`P)"E!TD70!X!;X`3\`DRA&2T9/\/\R`2$"
M-?OW'.VH1?+16DA/\/\R6DL!(7A$`I<#D'M$S?@`L"!&`9,`(X?X*#!42WM$
M^_<&[7?F#)M?:``O/_0AKCA&^_?@[`,H?_8;KDU)!#@X1'E$^_<.[``H"+\^
M1A#FP_%``O@8`"'[]PSM4$;[]_W^.$8X(@`A^_<$[5SG#)N;>$$K?_2)K@R;
MVWA#*W_TA*X,FQMY2"M_]'^N#)M;>44K?_1ZK@"53_#_,PZ=;_`Y`BA&^_=J
M[`R>*$8I(C)-,4;[]^KK,4M]1$_P_S)[1`&3+TL!(0*6($;-^`"P>T0#E?OW
MKNP>YOOW$NR)J\WO`````/[<NI@`````=E0R$`````#PX=+#``````$C16<`
M````R%L!`&!:`0`8`0``>`L``%8,``"B"P``@@H``&H+```@`0``*`$``+@+
M``#B"@``$`L``)0*``#J"0``7`D```H)``!2"@``^`@``'`+``!*"@``7`L`
M`%X(``!""0``$`<``"((``"<!0``W@8``+(&``!P!P``Z@0``"X&``"52I9)
M+>GP3WI$A["42P2M`I506`%H`Y`%D=98,&C[]]KL!$8P:/OWUNPI1I#X:#",
M2(3X:3!X1/[WKOX8L0-X,2L`\-F`__>9^C!H^_?"[(5)"R,!(GE$^_?RZP`H
M2=""2P)I>T1;:-+X&(`!*T'=W_C\H4_T@&G?^/BQP/(@"?I$`"7[1`$D(^`!
M:-KX"`"+:%#X)'`)Z@,#L_6`;PB_"6D*T#!H`9+[]Y3L`9H"(Q%H`"+[]Y3K
M`48X1OOW$.L`*$#PD8#;^`0P`30!-:-"#=TP:/OW?NPJ1@`C04;[]S[L`D8`
M*-#18TM[1%MH6AZJ0FG0,&C[]V[L8$D#(P$B>43[]Y[K!$9PL3!H^_=B["-I
M6TH9:'I$^_=0ZR-I&VB;:%L"`/&#@#!H^_=4[%5)`R,!(GE$^_>$ZP1&>+%2
M2`*9>$3^]RC^!48P:``M8]#[]T#L(VDJ1AEH^_<PZS!H^_<X[$E-?40$1C!H
M^_<R[$=)`2)Y1/OWCNM&2GI$`48@1OOW'.LP:/OW).P`(@*9`T9!2(/X:2!X
M1/[W_?T$1NA@<+-/].!Q($;[]YSK0QP1*!B_`2M$V`.;!9H;:)I"/=$'L+WH
M\(\!*Y/=,TT!)'U$,&@!-/OW_NM!1OOWJNIK:*-"]=R%YRU+>T1;:%H>JD)_
M]'^OY^=#>``K/_0EKR'GJ&C_]P3[!$;H8``HR=$D2'A$^_=0Z_OWW.LB2R)I
M>T2;:!!H&6C^]XS_E^<P:/OWT.LC:1EH^_=FZW3G^_>>ZAI)`T8:2")&>41X
M1(EH"6C[]S+K`+^(4@$`&`$``"`!```:!```L@4``,13`0"H4P$`I%,!`#Y3
M`0`0!0``_@0``.@$``#&`@``PE(!`*P$``"\!```9`(``%A2`0`^4@$`+@0`
M``A2`0#>40$`&`0``#BU!4;_]PKY`WC#L4(<!$8O*PB_%$82^`$[`"OXT?_W
M%?H`+1B_`"@(T"MX,[$'22!&>43[]_3IA$("T#B]!$;MYRA&O>@X0/[W@+X^
M`@``!4L0M'M$!4P;60.Q&VA=^`1+^_<WN@"_B$\!`#`!```MZ?A#!T8+3HA&
M"TV11GY$^_>^Z7U$=ANV$`G0`"0!-%7X!#M*1D%&.$:81Z9"]M&]Z/B#1DX!
M`#Q.`0!P1P"_"$`MZ0B`O>@!``(`<&5R;'AS:2YC````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````)7,O)7,````O<')O8R]S96QF+V5X
M90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%2
M7U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),
M3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!
M4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U0
M1$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?
M0TQ%04X]```Q````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E
M<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP`````+G!A
M<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP
M+25U+25U)7,`````4$%42``````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*``!!4D=6`````!@```!P97)L`````#````!005(Z.E!A
M8VME<CHZ5D524TE/3@`````Q+C`S-P```%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM
M``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M
M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R
M=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM
M;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM
M>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O
M9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M
M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M
M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970[
M"F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S
M<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y0
M05(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S
M:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*
M;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS
M965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K
M(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E
M<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL
M92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT
M(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]
M"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES
M="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L
M87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H
M)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F
M:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N
M86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F
M:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M
M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q
M("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z
M.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM
M;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C
M86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG
M+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B
M)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP
M,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P
M;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E
M="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S
M>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S
M=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B
M+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,
M13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI
M('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F
M:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N
M<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE
M("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO
M<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@
M,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@
M-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS
M92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I
M92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP
M<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D
M=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@
M)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U
M;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.
M5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N
M*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF
M("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!
M4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE
M+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[
M7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N
M86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*`(QX_W\!````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#%&```A1@````````!`````0````$```#?`0``
M`0```"X"```!````B0,```P```#,$@``#0```'Q?```9````D*T!`!L````$
M````&@```)2M`0`<````!````/7^_V^T`0``!0```)`)```&````H`(```H`
M```%!0``"P```!`````5``````````,```"LK@$``@`````"```4````$0``
M`!<```#,$```$0```-0/```2````^````!,````(````'@````@```#[__]O
M`0``"/[__V]T#P``____;P,```#P__]OE@X``/K__V\1````````````````
M`````````````````````````````````````````)RM`0```````````-@2
M``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(`
M`-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``
MV!(``-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``#8
M$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(``-@2
M``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``#8$@``V!(`
M`-@2``#8$@``V!(``-@2``#8$@``V!(``-@2``!Y7P``````````````````
M```````````````````````````$L`$``````#U?````````^14`````````
M````````````````````!+`!`/_____L8@``%&````````#48```V&```.!B
M```<8```Z&(```````#,8@``U&(```````#T8@``1T-#.B`H56)U;G1U+TQI
M;F%R;R`V+C0N,"TR=6)U;G1U,2D@-BXT+C`@,C`Q-S`W,C0`1T-#.B`H56)U
M;G1U+TQI;F%R;R`V+C0N,"TQ=6)U;G1U,BD@-BXT+C`@,C`Q-S`W,#0`03(`
M``!A96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<
M`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU
M+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YD871A`"YB
M<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````
M````````````````````````````````"P````$````"````5`$``%0!```9
M```````````````!`````````!,````'`````@```'`!``!P`0``(```````
M````````!``````````A````!P````(```"0`0``D`$``"0`````````````
M``0`````````-````/;__V\"````M`$``+0!``#L````!0`````````$````
M!````#X````+`````@```*`"``"@`@``\`8```8````#````!````!````!&
M`````P````(```"0"0``D`D```4%``````````````$`````````3@```/__
M_V\"````E@X``)8.``#>````!0`````````"`````@```%L```#^__]O`@``
M`'0/``!T#P``8`````8````#````!`````````!J````"0````(```#4#P``
MU`\``/@````%``````````0````(````<P````D```!"````S!```,P0````
M`@``!0```!8````$````"````'P````!````!@```,P2``#,$@``#```````
M````````!`````````!W`````0````8```#8$@``V!(``"`#````````````
M``0````$````@@````$````&````^!4``/@5``"$20`````````````(````
M`````(@````!````!@```'Q?``!\7P``"```````````````!`````````".
M`````0````(```"$7P``A%\``*0_``````````````0`````````E@````$`
M`'""````*)\``"B?```(````#0`````````$`````````*$````!`````@``
M`#"?```PGP``!```````````````!`````````"K````#@````,```"0K0$`
MD*T```0```````````````0````$````MP````\````#````E*T!`)2M```$
M```````````````$````!````,,````!`````P```)BM`0"8K0``!```````
M````````!`````````#(````!@````,```"<K0$`G*T``!`!```&````````
M``0````(````T0````$````#````K*X!`*RN``!4`0`````````````$````
M!````-8````!`````P````"P`0``L```0```````````````!`````````#<
M````"`````,```!`L`$`0+```!@0``````````````0`````````X0````$`
M```P`````````$"P``!F```````````````!`````0```.H````#``!P````
M``````"FL```,P```````````````0`````````!`````P``````````````
8V;```/H```````````````$`````````
